Skip to contents

dm_hct() chains together dm_extract(), dm_standardize(), and dm_combine() to provide a single wrapper function for data preparation.

Usage

dm_hct(dm_remote = dm_sql_server(), ..., .excl_dsmb = FALSE, .quiet = FALSE)

Arguments

dm_remote

[dm] A dm object connected to the remote SQL server database

...

Names of tables to select; if provided, only these tables will be extracted

.excl_dsmb

[lgl] [Deprecated] This information is no longer available in the remote database.

.quiet

Should status messages be suppressed?

Value

The prepared dm object