Skip to contents

dm_standardize() takes a local version of the SQL server as input and standardizes all columns across all tables. Standardization procedures are based on both column type and the typing prefix of the column name. Specifically, columns are standardized using the following workflow:

  1. Columns with type character or chr/cat/lgl/mcat/intvl prefixes are passed to std_chr()

  2. Columns with type logical or the lgl prefix are passed to std_lgl()

  3. Columns with type numeric or integer, or num/pct prefixes, are passed to std_num()

  4. Columns with the intvl prefix are passed to std_intvl()

  5. Column with types Date, POSIXct, or POSIXlt, or with dt/dttm/date prefixes, are passed to std_date()

After standardization, tables are sorted into alphabetical order before returning.

Usage

dm_standardize(dm_local = dm_extract(), quiet = FALSE)

Arguments

dm_local

A local dm object containing MLinHCT data from dm_extract()

quiet

Whether to suppress progress messages

Value

The input dm with standarized column values