Skip to contents

A previous version of the dmhct pipeline performed all transformations of tables simultaneously; to ensure backwards compatibility, this behavior has been retained in dm_transform(). However, it is strongly recommended that new code not use dm_transform() and instead use the updated pipeline.

Usage

dm_transform(dm_local = dm_extract_legacy(), reset = FALSE)

Arguments

dm_local

[dm] A local dm object from dm_extract()

reset

[lgl(1)] Should the cache be reset to the current results, even if inputs have not changed? This is useful if data processing logic has changed, but the underlying data have not.

Value

[dm] The updated dm object