Skip to contents

na_patterns is a collection of regular expression that commonly represent missing data, especially when the character vector should be converted to something else. These are designed to match strings that have already been standardized.

Usage

na_patterns

Format

An object of class character of length 8.