Select and Convert Table + Columns From Remote Source
Source:R/legacy_dm_extract.R
dm_extract_legacy.Rddm_extract_legacy() is a previous, less extensible version of dm_extract().
It selects tables and columns of potential interest. It combines all
Cerner tables into one and joins HLA tables.
Usage
dm_extract_legacy(dm_remote = dm_sql_server(), collect = TRUE, reset = FALSE)Arguments
- dm_remote
[dm]Admobject connected to the SQL Server for MLinHCT- collect
[lgl(1)]Should tables be collected locally on output?- reset
[lgl(1)]Should the cache be reset to the current results, even if inputs have not changed? This is useful if data processing logic has changed, but the underlying data have not.