dm_standardize() takes a local version of the SQL server as input and
standardizes all columns across all tables. Standardization procedures are
based on both column type and the typing prefix of the column name. Specifically,
columns are standardized using the following workflow:
Columns with type
characteror chr/cat/lgl/mcat/intvl prefixes are passed tostd_chr()Columns with type
logicalor the lgl prefix are passed tostd_lgl()Columns with type
numericorinteger, or num/pct prefixes, are passed tostd_num()Columns with the intvl prefix are passed to
std_intvl()Column with types
Date,POSIXct, orPOSIXlt, or with dt/dttm/date prefixes, are passed tostd_date()
After standardization, tables are sorted into alphabetical order before returning.
Usage
dm_standardize(dm_local = dm_extract(), quiet = FALSE)Arguments
- dm_local
A local
dmobject containing MLinHCT data fromdm_extract()- quiet
Whether to suppress progress messages