na_patterns is a collection of regular expression that commonly represent
missing data, especially when the character vector should be converted to
something else. These are designed to match strings that have already been
standardized.
na_patterns is a collection of regular expression that commonly represent
missing data, especially when the character vector should be converted to
something else. These are designed to match strings that have already been
standardized.